// Copyright (c) 2026 The Chromium Embedded Framework Authors. All rights
// reserved. Use of this source code is governed by a BSD-style license that
// can be found in the LICENSE file.
//
// ---------------------------------------------------------------------------
//
// This file was generated by the CEF translator tool. If making changes by
// hand only do so within the body of existing method and function
// implementations. See the translator.README.txt file in the tools directory
// for more information.
//
// $hash=9b5f6180b773e43ab7a3189b0d02a12d7e8c9391$
//

#ifndef CEF_LIBCEF_DLL_CPPTOC_MEDIA_ROUTE_CREATE_CALLBACK_CPPTOC_H_
#define CEF_LIBCEF_DLL_CPPTOC_MEDIA_ROUTE_CREATE_CALLBACK_CPPTOC_H_
#pragma once

#if !defined(WRAPPING_CEF_SHARED)
#error This file can be included wrapper-side only
#endif

#include "include/capi/cef_media_router_capi.h"
#include "include/cef_media_router.h"
#include "libcef_dll/cpptoc/cpptoc_ref_counted.h"

// Wrap a C++ class with a C structure.
// This class may be instantiated and accessed wrapper-side only.
class CefMediaRouteCreateCallbackCppToC
    : public CefCppToCRefCounted<CefMediaRouteCreateCallbackCppToC,
                                 CefMediaRouteCreateCallback,
                                 cef_media_route_create_callback_t> {
public:
  CefMediaRouteCreateCallbackCppToC();
  virtual ~CefMediaRouteCreateCallbackCppToC();
};

constexpr auto CefMediaRouteCreateCallbackCppToC_Wrap =
    CefMediaRouteCreateCallbackCppToC::Wrap;
constexpr auto CefMediaRouteCreateCallbackCppToC_Unwrap =
    CefMediaRouteCreateCallbackCppToC::Unwrap;

#endif // CEF_LIBCEF_DLL_CPPTOC_MEDIA_ROUTE_CREATE_CALLBACK_CPPTOC_H_
