// Copyright (c) 2026 The Chromium Embedded Framework Authors. All rights
// reserved. Use of this source code is governed by a BSD-style license that
// can be found in the LICENSE file.
//
// ---------------------------------------------------------------------------
//
// This file was generated by the CEF translator tool. If making changes by
// hand only do so within the body of existing method and function
// implementations. See the translator.README.txt file in the tools directory
// for more information.
//
// $hash=c78a98c53c9c3c64317e0a5ff697f49c63245d4a$
//

#ifndef CEF_LIBCEF_DLL_CTOCPP_COMPONENT_UPDATER_CTOCPP_H_
#define CEF_LIBCEF_DLL_CTOCPP_COMPONENT_UPDATER_CTOCPP_H_
#pragma once

#if !defined(WRAPPING_CEF_SHARED)
#error This file can be included wrapper-side only
#endif

#include "include/capi/cef_component_updater_capi.h"
#include "include/cef_component_updater.h"
#include "libcef_dll/ctocpp/ctocpp_ref_counted.h"
#include <vector>

#if CEF_API_ADDED(14600)

// Wrap a C structure with a C++ class.
// This class may be instantiated and accessed wrapper-side only.
class CefComponentUpdaterCToCpp
    : public CefCToCppRefCounted<CefComponentUpdaterCToCpp, CefComponentUpdater,
                                 cef_component_updater_t> {
public:
  CefComponentUpdaterCToCpp();
  virtual ~CefComponentUpdaterCToCpp();

  // CefComponentUpdater methods.
  size_t GetComponentCount() override;
  void GetComponents(std::vector<CefRefPtr<CefComponent>> &components) override;
  CefRefPtr<CefComponent>
  GetComponentByID(const CefString &component_id) override;
  void Update(const CefString &component_id,
              cef_component_update_priority_t priority,
              CefRefPtr<CefComponentUpdateCallback> callback) override;
};

constexpr auto CefComponentUpdaterCToCpp_Wrap = CefComponentUpdaterCToCpp::Wrap;
constexpr auto CefComponentUpdaterCToCpp_Unwrap =
    CefComponentUpdaterCToCpp::Unwrap;

#endif // CEF_API_ADDED(14600)

#endif // CEF_LIBCEF_DLL_CTOCPP_COMPONENT_UPDATER_CTOCPP_H_
